@@ -1,19 +1,24 @@
+"""
+codebooks: automatic generation of codebooks from dataframes
+"""
+
 # Re-exported imports
 from codebooks import html
 from codebooks.variable import Variable
 
 # Hidden imports
 from htmlmin import minify as _minify
-from pkg_resources import get_distribution as _get_distribution
+from importlib import resources
 
-__version__ = _get_distribution("codebooks").version
+__version__ = resources.read_text(__name__, "VERSION").strip()
 
 def htmlbook(df, title="Codebook", outfile=None, desc={}):
 
     output = [html.header(title, len(df.columns), len(df))]
 
-    for varname in df.columns:
+    for i, varname in enumerate(df.columns):
         var = Variable(df[varname], desc.get(varname, ""))
+        var.index = i
         output.append(str(html.Summary(var)))
 
     output.append(html.footer)
@@ -25,4 +30,3 @@ def htmlbook(df, title="Codebook", outfile=None, desc={}):
             f.write(output)
     else:
         return output
-
